@@ -64,6 +64,7 @@ MainWindow::MainWindow(QWidget *parent) :
  ui->comboBox_type->addItem("93_EEPROM", 2);
  ui->comboBox_type->addItem("25_EEPROM", 3);
  ui->comboBox_type->addItem("95_EEPROM", 4);
+ ui->comboBox_type->addItem("45_EEPROM", 5);
 
  ui->comboBox_addr4bit->addItem("No", 0);
  ui->comboBox_addr4bit->addItem("Yes", 0x01);
@@ -80,7 +81,9 @@ MainWindow::MainWindow(QWidget *parent) :
  ui->comboBox_page->addItem("64", 64);
  ui->comboBox_page->addItem("128", 128);
  ui->comboBox_page->addItem("256", 256);
+ ui->comboBox_page->addItem("264", 264);
  ui->comboBox_page->addItem("512", 512);
+ ui->comboBox_page->addItem("528", 528);
 
  ui->comboBox_block->addItem(" ", 0);
  ui->comboBox_block->addItem("64 K", 64 * 1024);
@@ -102,6 +105,8 @@ MainWindow::MainWindow(QWidget *parent) :
  chipData.resize(256);
  chipData.fill(char(0xff));
  ch341a_spi_shutdown();
+ QFont heFont;
+ heFont = QFont("Monospace", 10);
  hexEdit = new QHexEdit(ui->frame);
  hexEdit->setGeometry(0,0,ui->frame->width(),ui->frame->height());
  hexEdit->setData(chipData);
@@ -110,6 +115,7 @@ MainWindow::MainWindow(QWidget *parent) :
  hexEdit->setAsciiFontColor(defaultTextColor);
  hexEdit->setAddressFontColor(defaultTextColor);
  hexEdit->setHexFontColor(defaultTextColor);
+ hexEdit->setFont(heFont);
  QStringList commandLineParams = QCoreApplication::arguments();
  QString commandLineFileName ="";
  if (commandLineParams.count() > 1)
@@ -143,7 +149,8 @@ void MainWindow::on_pushButton_clicked()
          ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 1)) ||
          ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 2)) ||
          ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 3)) ||
-         ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 4)))
+         ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 4)) ||
+         ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 5)))
     {
        doNotDisturb();
        if (currentChipType == 1)
@@ -151,7 +158,7 @@ void MainWindow::on_pushButton_clicked()
            currentBlockSize = 128;
            currentNumBlocks = currentChipSize / currentBlockSize;
        }
-       if ((currentChipType == 2) ||(currentChipType == 3) || (currentChipType == 4))
+       if ((currentChipType == 2) ||(currentChipType == 3) || (currentChipType == 4) || (currentChipType == 5))
        {
            currentBlockSize = currentPageSize;
            currentNumBlocks = currentChipSize / currentBlockSize;
@@ -194,6 +201,10 @@ void MainWindow::on_pushButton_clicked()
                  //95xxx
                  res = s95_read_param(buf,curBlock * currentBlockSize, currentBlockSize, currentBlockSize, currentAlgorithm);
               break;
+              case 5:
+                 //45xx
+                 res = at45_read_param(buf,curBlock * currentBlockSize, currentBlockSize, currentBlockSize, currentAlgorithm);
+              break;
               default:
                  //Unsupport
                  QMessageBox::about(this, tr("Error"), tr("Unsupported chip type!"));
@@ -258,6 +269,7 @@ void MainWindow::on_pushButton_2_clicked()
 {
     timer->stop();
     //searching the connected chip in database
+    u8 sr;
     statusCH341 = ch341a_spi_init();
     ch341StatusFlashing();
     if (statusCH341 != 0)
@@ -273,7 +285,7 @@ void MainWindow::on_pushButton_2_clicked()
     // print JEDEC info
     unsigned char bufid[5]={0xff,0xff,0xff,0xff,0xff};
     snor_read_devid(bufid, 5);
-    if ((bufid[0] == 0xff) && (bufid[1] == 0xff) && (bufid[2] == 0xff))
+    if ((bufid[0] == 0xff) && (bufid[1] == 0xff) && (bufid[2] == 0xff) && (currentChipType != 5))
     {
         QMessageBox::about(this, tr("Error"), tr("The chip is not connect or missing!"));
         ui->pushButton_2->setStyleSheet(grnKeyStyle);
@@ -286,17 +298,21 @@ void MainWindow::on_pushButton_2_clicked()
     {
         if ((bufid[0] == chips[i].chipJedecIDMan) && (bufid[1] == chips[i].chipJedecIDDev) && (bufid[2] == chips[i].chipJedecIDCap))
         {            
+            index = ui->comboBox_type->findText(chips[i].chipTypeTxt);
+            if ( index != -1 )
+            { // -1 for not found
+               ui->comboBox_type->setCurrentIndex(index);
+            }
             index = ui->comboBox_man->findText(chips[i].chipManuf);
-                        if ( index != -1 )
-                        { // -1 for not found
-                           ui->comboBox_man->setCurrentIndex(index);
-                        }
-                        index = ui->comboBox_name->findText(chips[i].chipName);
-                                    if ( index != -1 )
-                                    { // -1 for not found
-                                       ui->comboBox_name->setCurrentIndex(index);
-                                    }
-
+            if ( index != -1 )
+            { // -1 for not found
+                ui->comboBox_man->setCurrentIndex(index);
+            }
+            index = ui->comboBox_name->findText(chips[i].chipName);
+            if ( index != -1 )
+            { // -1 for not found
+                ui->comboBox_name->setCurrentIndex(index);
+            }
             index = ui->comboBox_size->findData(chips[i].chipSize);
             if ( index != -1 )
             { // -1 for not found
@@ -327,6 +343,128 @@ void MainWindow::on_pushButton_2_clicked()
             break;
         }
     }
+
+    // 45xxx without JEDEC info
+    if ((currentChipType == 5) && (bufid[0] == 0xff) && (bufid[1] == 0xff) && (bufid[2] == 0xff) )
+    {
+        //calculating capacity
+        int capacityIndex = 0;
+        if (!at45_read_sr(&sr))
+        {
+            if ((sr & 0xC0) == 0x80) //45xx chip found
+            {
+                sr = sr & 0x38;
+                switch (sr)
+                   {
+                   case 0x08:
+                      //132K
+                      capacityIndex = 1;
+                   break;
+                   case 0x10:
+                      //264K
+                      capacityIndex = 2;
+                   break;
+                   case 0x18:
+                      //528K
+                      capacityIndex = 3;
+                   break;
+                   case 0x20:
+                      //1056K
+                      capacityIndex = 4;
+                   break;
+                   case 0x28:
+                      //2112K
+                      capacityIndex = 5;
+                   break;
+                   case 30:
+                      //4224K
+                      capacityIndex = 6;
+                   break;
+                   }
+                ui->comboBox_size->setCurrentIndex(capacityIndex);
+                for (i = 0; i< max_rec; i++)
+                {
+                    if ((chips[i].chipTypeHex == 0x05) && (chips[i].chipSize == ui->comboBox_size->currentData().toUInt()))
+                    {
+                       if (!QString::compare(chips[i].chipManuf, "ATMEL", Qt::CaseInsensitive))
+                       {
+                           index = ui->comboBox_type->findText(chips[i].chipTypeTxt);
+                           if ( index != -1 )
+                           { // -1 for not found
+                              ui->comboBox_type->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_man->findText(chips[i].chipManuf);
+                           if ( index != -1 )
+                           { // -1 for not found
+                               ui->comboBox_man->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_name->findText(chips[i].chipName);
+                           if ( index != -1 )
+                           { // -1 for not found
+                               ui->comboBox_name->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_size->findData(chips[i].chipSize);
+                           if ( index != -1 )
+                           { // -1 for not found
+                              ui->comboBox_size->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_page->findData(chips[i].sectorSize);
+                           if ( index != -1 )
+                           { // -1 for not found
+                              ui->comboBox_page->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_block->findData(chips[i].blockSize);
+                           if ( index != -1 )
+                           { // -1 for not found
+                              ui->comboBox_block->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_addr4bit->findData(chips[i].addr4bit);
+                           if ( index != -1 )
+                           { // -1 for not found
+                              ui->comboBox_addr4bit->setCurrentIndex(index);
+                           }
+                           index = ui->comboBox_vcc->findText(chips[i].chipVCC);
+                           if ( index != -1 )
+                           { // -1 for not found
+                              ui->comboBox_vcc->setCurrentIndex(index);
+                           }
+
+                           ui->pushButton_2->setStyleSheet(grnKeyStyle);
+                           break;
+                       }
+                    }
+                }
+            }
+        }
+
+    }
+
+    if ((currentChipType == 5) && (ui->comboBox_size->currentIndex() > 0))
+    {
+        //calculate buffer size
+        if (!at45_read_sr(&sr))
+        {
+            if ((sr & 0x01) == 1)
+            {
+                if ( ui->comboBox_page->currentData() == 264)
+                {
+                    index = ui->comboBox_page->findData(256);
+                    if ( index != -1 )
+                    { // -1 for not found
+                       ui->comboBox_page->setCurrentIndex(index);
+                    }
+                }
+                if ( ui->comboBox_page->currentData() == 528)
+                {
+                    index = ui->comboBox_page->findData(512);
+                    if ( index != -1 )
+                    { // -1 for not found
+                       ui->comboBox_page->setCurrentIndex(index);
+                    }
+                }
+            }
+        }
+    }
     currentChipSize = ui->comboBox_size->currentData().toUInt();
     currentBlockSize = ui->comboBox_block->currentData().toUInt();
     currentPageSize = ui->comboBox_page->currentData().toUInt();
@@ -432,6 +570,7 @@ void MainWindow::on_actionSave_triggered()
 void MainWindow::on_actionErase_triggered()
 {
     //statusCH341 = ch341a_spi_init();
+    int ret;
     statusCH341 = ch341a_init(currentChipType);
     ch341StatusFlashing();
     if (statusCH341 != 0)
@@ -446,9 +585,32 @@ void MainWindow::on_actionErase_triggered()
     doNotDisturb();
     if (currentChipType == 0)
     {
-       ui->progressBar->setValue(50);
-       full_erase_chip();
-       sleep(1);
+       if (currentNumBlocks > 0)
+       {
+           ui->progressBar->setRange(0, static_cast<int>(currentNumBlocks));
+           for (uint32_t curBlock = 0; curBlock < currentNumBlocks; curBlock++)
+           {
+               //config_stream(2);
+               ret = snor_block_erase( curBlock,  currentBlockSize, static_cast<u8>(currentAddr4bit));
+               if (ret != 0)
+                 {
+                   QMessageBox::about(this, tr("Error"), tr("Error erasing sector ") + QString::number(curBlock));
+                   ch341a_spi_shutdown();
+                   doNotDisturbCancel();
+                   return;
+                 }
+               qApp->processEvents();
+               ui->progressBar->setValue( static_cast<int>(curBlock));
+               if (isHalted)
+               {
+                   isHalted = false;
+                   ch341a_spi_shutdown();
+                   doNotDisturbCancel();
+                   return;
+               }
+           }
+       }
+
     }
     if ((currentChipType == 4) || ((currentChipType == 3) && ((currentAlgorithm & 0x20) == 0)))
     {
@@ -539,6 +701,23 @@ void MainWindow::on_actionErase_triggered()
         }
 
     }
+    if ((currentChipType == 5) && ((currentAlgorithm & 0x10) > 0))
+    {
+        ui->progressBar->setValue(50);
+        at45_full_erase();
+        sleep(1);
+    }
+    if ((currentChipType == 5) && ((currentAlgorithm & 0x10) == 0))
+    {
+        uint32_t blocks = currentChipSize / currentPageSize / 8;
+        ui->progressBar->setRange(0, static_cast<int>(blocks));
+        uint32_t curBlock = 0;
+        for (curBlock = 0; curBlock < blocks; curBlock++)
+        {
+            at45_sector_erase(curBlock,  currentPageSize);
+             ui->progressBar->setValue(static_cast<int>(curBlock));
+        }
+    }
     doNotDisturbCancel();
     ui->checkBox->setStyleSheet("");
     ui->statusBar->showMessage("");
@@ -651,7 +830,8 @@ void MainWindow::on_actionWrite_triggered()
          ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 1)) ||
          ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 2)) ||
          ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 3)) ||
-         ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 4)))
+         ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 4)) ||
+         ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 5)))
         {
         doNotDisturb();
         if (currentChipType == 1)
@@ -659,7 +839,7 @@ void MainWindow::on_actionWrite_triggered()
             currentBlockSize = 128;
             currentNumBlocks = currentChipSize / currentBlockSize;
         }
-        if ((currentChipType == 2) || (currentChipType == 3) || (currentChipType == 4))
+        if ((currentChipType == 2) || (currentChipType == 3) || (currentChipType == 4)|| (currentChipType == 5))
         {
             currentBlockSize = currentPageSize;
             currentNumBlocks = currentChipSize / currentBlockSize;
@@ -705,6 +885,10 @@ void MainWindow::on_actionWrite_triggered()
                           //M95xx
                           res =  s95_write_param(buf, addr, currentBlockSize, currentBlockSize, currentAlgorithm);                         
                        break;
+                       case 5:
+                          //AT45DBxx
+                          res =  at45_write_param(buf, addr, currentBlockSize, currentBlockSize, currentAlgorithm);
+                       break;
                        default:
                           //Unsupport
                           QMessageBox::about(this, tr("Error"), tr("Unsupported chip type!"));
@@ -872,7 +1056,8 @@ void MainWindow::on_actionVerify_triggered()
             ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 1)) ||
             ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 2)) ||
             ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 3)) ||
-            ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 4)))
+            ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 4)) ||
+            ((currentNumBlocks > 0) && (currentPageSize >0) && (currentChipType == 5)))
            {
                ui->crcEdit->setText("");
                doNotDisturb();
@@ -881,7 +1066,7 @@ void MainWindow::on_actionVerify_triggered()
                  currentBlockSize = 128;
                  currentNumBlocks = currentChipSize / currentBlockSize;
                }
-               if ((currentChipType == 2) || (currentChipType == 3) || (currentChipType == 4))
+               if ((currentChipType == 2) || (currentChipType == 3) || (currentChipType == 4) || (currentChipType == 5))
                {
                    currentBlockSize = currentPageSize;
                    currentNumBlocks = currentChipSize / currentBlockSize;
@@ -923,6 +1108,9 @@ void MainWindow::on_actionVerify_triggered()
                          //95xxx
                          res = s95_read_param(buf,curBlock * currentBlockSize, currentBlockSize, currentBlockSize, currentAlgorithm);
                       break;
+                      case 5:
+                         res = at45_read_param(buf,curBlock * currentBlockSize, currentBlockSize, currentBlockSize, currentAlgorithm);
+                      break;
                       default:
                          //Unsupport
                          QMessageBox::about(this, tr("Error"), tr("Unsupported chip type!"));
@@ -1192,6 +1380,16 @@ void MainWindow::on_comboBox_type_currentIndexChanged(int index)
           ui->comboBox_size->addItem("256 K", 256 * 1024);
           ui->comboBox_size->addItem("512 K", 512 * 1024);
        break;
+       case 5:
+          //95xxx
+          ui->comboBox_size->addItem("132 K",   132 * 1024);
+          ui->comboBox_size->addItem("264 K",   264 * 1024);
+          ui->comboBox_size->addItem("528 K",   528 * 1024);
+          ui->comboBox_size->addItem("1056 K", 1056 * 1024);
+          ui->comboBox_size->addItem("2112 K", 2112 * 1024);
+          ui->comboBox_size->addItem("4224 K", 4224 * 1024);
+          ui->comboBox_size->addItem("8448 K", 8448 * 1024);
+       break;
        default:
           //Unsupport
        return;
@@ -1243,6 +1441,11 @@ void MainWindow::on_comboBox_type_currentIndexChanged(int index)
          ui->actionDetect->setDisabled(true);
          ui->actionChip_info->setEnabled(true);
      }
+     if (index == 5)
+     {
+          ui->pushButton_2->show();
+          ui->actionDetect->setEnabled(true);
+     }
 }
 
 void MainWindow::on_comboBox_addr4bit_currentIndexChanged(int index)
@@ -1389,12 +1592,13 @@ void MainWindow::on_pushButton_4_clicked()
     //info form showing
     DialogInfo* infoDialog = new DialogInfo();
     infoDialog->show();
-    if ((currentChipType == 0) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(2);
-    if ((currentChipType == 0) && (ui->comboBox_vcc->currentIndex() == 2)) infoDialog->setChip(3);
-    if ((currentChipType == 1) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(1);
-    if ((currentChipType == 2) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(4);
-    if ((currentChipType == 3) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(2);
-    if ((currentChipType == 4) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(2);
+    if ((currentChipType == 0) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(2); //NOR_FLASH 1.8
+    if ((currentChipType == 0) && (ui->comboBox_vcc->currentIndex() == 2)) infoDialog->setChip(3); //NOR FLASH 3.3
+    if ((currentChipType == 1) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(1); //24xxx 3.3
+    if ((currentChipType == 2) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(4); //93xxx 3.3
+    if ((currentChipType == 3) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(2); //25xxx 3.3
+    if ((currentChipType == 4) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(2); //95xxx 3.3
+    if ((currentChipType == 5) && (ui->comboBox_vcc->currentIndex() == 1)) infoDialog->setChip(5); //45xxx 3.3
 }
 
 void MainWindow::on_actionChip_info_triggered()
